==> d4science-iam-client-1.1.0-20260209.145556-2-servicearchive.tar.gz: README.md <==
# d4science-iam-client

> Helper library to support all the OIDC token generation and verification

[![License: EUPL-1.2](./images/License-EUPL--1.2-blue.svg)](LICENSE.md)
[![Changelog](./images/Changelog-keep.svg)](CHANGELOG.md)
[![Cite](./images/Cite-CITATION.cff-orange.svg)](CITATION.cff)

## Table of contents
- [Overview](#overview)
- [Documentation](#documentation)
- [Changelog](#changelog)
- [Authors](#authors)
- [How to cite](#how-to-cite)
- [License](#license)
- [About gCube](#about-gcube)
- [Funding](#funding)

## Overview

* The source code is present in `src` folder.

## Documentation

* To build the library JAR it is sufficient to type

    mvn clean package

## Changelog

See [CHANGELOG.md](CHANGELOG.md).

## Authors

* **Mauro Mugnaini** ([Nubisware S.r.l.](http://www.nubisware.com))

## How to Cite

If you use this software, please cite it using the metadata in [CITATION.cff](CITATION.cff) 

## License

This project is licensed under the terms specified in the [LICENSE.md](LICENSE.md) file.

## About gCube

This software is part of the [gCube Framework](https://www.gcube-system.org/): an open-source software toolkit used for building and operating Hybrid Data Infrastructures enabling the dynamic deployment of [Virtual Research Environments](https://en.wikipedia.org/wiki/Virtual_research_environment) by favouring the realisation of reuse oriented policies. The gCube Framework supports the development and operation of the [D4Science Infrastructure](https://www.d4science.org). 

## Funding

See [FUNDING.md](FUNDING.md)

==> d4science-iam-client-1.1.0-20260210.110807-3-servicearchive.tar.gz: README.md <==
# d4science-iam-client

> Helper library to support all the OIDC token generation and verification

[![License: EUPL-1.2](./images/License-EUPL--1.2-blue.svg)](LICENSE.md)
[![Changelog](./images/Changelog-keep.svg)](CHANGELOG.md)
[![Cite](./images/Cite-CITATION.cff-orange.svg)](CITATION.cff)

## Table of contents
- [Overview](#overview)
- [Documentation](#documentation)
- [Chanagelog](#changelog)
- [Authors](#authors)
- [How to cite](#how-to-cite)
- [License](#license)
- [About gCube](#about-the-gcube-framework)
- [Funding](#funding)

## Overview

* [OpenJDK](https://openjdk.java.net/) - The JDK used
* [Maven](https://maven.apache.org/) - Dependency Management

## Documentation

To build the library JAR it is sufficient to type

    mvn clean package

## Changelog

See [Releases](https://code-repo.d4science.org/gCubeSystem/d4science-iam-client/releases).


## Authors

* **Mauro Mugnaini** ([Nubisware S.r.l.](http://www.nubisware.com))


## How to Cite

If you use this software, please cite it using the metadata in [CITATION.cff](CITATION.cff) 

## License

This project is licensed under the terms specified in the [LICENSE.md](LICENSE.md) file.

## About the gCube Framework

This software is part of the [gCube Framework](https://www.gcube-system.org/): an open-source software toolkit used for building and operating Hybrid Data Infrastructures enabling the dynamic deployment of [Virtual Research Environments](https://en.wikipedia.org/wiki/Virtual_research_environment) by favouring the realisation of reuse oriented policies. The gCube Framework supports the development and operation of the [D4Science Infrastructure](https://www.d4science.org). 

## Funding

See [FUNDING.md](FUNDING.md)
